In the hipMemset2D and hipMemset3D tests synchronize with the default stream after performing an async memset.

[ROCm/clr commit: cc5abec092]
Este commit está contenido en:
Vladislav Sytchenko
2019-10-15 17:15:49 -04:00
padre 91ceb7dd2b
commit 2bc49fb55c
Se han modificado 2 ficheros con 7 adiciones y 5 borrados
@@ -53,7 +53,7 @@ bool testhipMemset3D(int memsetval,int p_gpuDevice)
for (size_t i=0; i<elements; i++) {
A_h[i] = 1;
}
HIPCHECK ( hipMemset3D( devPitchedPtr, memsetval, extent) );
HIPCHECK(hipMemset3D( devPitchedPtr, memsetval, extent));
hipMemcpy3DParms myparms = {0};
myparms.srcPos = make_hipPos(0,0,0);
myparms.dstPos = make_hipPos(0,0,0);
@@ -103,7 +103,8 @@ bool testhipMemset3DAsync(int memsetval,int p_gpuDevice)
}
hipStream_t stream;
HIPCHECK(hipStreamCreate(&stream));
HIPCHECK ( hipMemset3DAsync( devPitchedPtr, memsetval, extent, stream) );
HIPCHECK(hipMemset3DAsync(devPitchedPtr, memsetval, extent, stream));
HIPCHECK(hipStreamSynchronize(stream));
hipMemcpy3DParms myparms = {0};
myparms.srcPos = make_hipPos(0,0,0);
myparms.dstPos = make_hipPos(0,0,0);